## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global srcname openapi-core
%global modname openapi_core

Name:           python-%{srcname}
Version:        0.14.5
Release:        %autorelease
Summary:        OpenAPI client-side and server-side support

License:        BSD-3-Clause
URL:            https://github.com/python-openapi/%{srcname}
# The GitHub archive has the tests; the PyPI sdist does not.
Source:         %{url}/archive/%{version}/%{srcname}-%{version}.tar.gz

# https://github.com/p1c2u/openapi-core/pull/389 adapted for 0.14.5
# https://bugzilla.redhat.com/show_bug.cgi?id=2175937#c1
Patch:          python-openapi-core-0.14.5-pathable.patch

BuildArch:      noarch

BuildRequires:  python3-devel

# Test dependencies; see [tool.poetry.dev-dependencies], but note that this
# contains both test dependencies and unwanted linters etc.
# Not packaged in EPEL9:
#BuildRequires:  python3dist(djangorestframework)
BuildRequires:  python3dist(httpx)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(responses)
BuildRequires:  python3dist(strict-rfc3339)
BuildRequires:  python3dist(webob)

%global _description %{expand:
Openapi-core is a Python library that adds client-side and server-side
support for the OpenAPI v3.0 and OpenAPI v3.1 specification.}

%description %_description


%package -n     python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %_description


# Not packaged in EPEL9: python3dist(django); therefore, we omit the
# corresponding extra.
%pyproject_extras_subpkg -n python3-openapi-core flask requests


%prep
%autosetup -n %{srcname}-%{version} -p1
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters
sed -r -i 's/--(cov|flake8)[^[:blank:]]*([[:blank:]]+[^-][^[:blank:]]+)?//g' \
    setup.cfg
# https://fedoraproject.org/wiki/Changes/DeprecatePythonMock
# We don’t need to offer this upstream because the mock dependency is already
# removed in a later release.
# The find-then-modify pattern keeps us from discarding mtimes on any sources
# that do not need modification.
find . -type f -name '*.py' -exec \
    gawk '/^import mock$/ { print FILENAME; nextfile }' '{}' '+' |
  xargs -r -t sed -r -i 's/^import mock$/from unittest &/'


%generate_buildrequires
# Not packaged in EPEL9: python3dist(django); therefore, we omit the
# corresponding extra.
%pyproject_buildrequires -x flask -x requests


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files %{modname}


%check
# Not packaged in EPEL9: python3dist(falcon)
ignore="${ignore-} --ignore-glob=*falcon*"
# Not packaged in EPEL9: python3dist(django)
ignore="${ignore-} --ignore-glob=*django*"

# Some kind of pytest compatibility issue:
# [...]
# /usr/lib/python3.9/site-packages/_pytest/fixtures.py:1172: in
#          wrap_function_to_error_out_if_called_directly
#     ).format(name=fixture_marker.name or function.__name__)
# E   AttributeError: 'str' object has no attribute '__name__'
ignore="${ignore-} --ignore=tests/integration/validation/test_read_only_write_only.py"
ignore="${ignore-} --ignore=tests/integration/validation/test_security_override.py"
# Some kind of pytest compatibility issue:
# E       TypeError: Unexpected keyword arguments passed to pytest.raises:
#          message
# E       Use context-manager form instead?
k="${k-}${k+ and } not (TestSchemaUnmarshallerCall and test_string_format_invalid_value)"

%pytest ${ignore-} -k "${k-}"


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE
%doc README.rst


%changelog
* Thu Mar 09 2023 Mattia Verga <mattia.verga@proton.me> - 0.14.5-1
- Initial package for EPEL9 (close RHBZ#2175937)

* Wed Dec 21 2022 Mattia Verga <mattia.verga@proton.me> - 0.16.2-1
- Initial import (fedora#2154240)
